@@ -18,10 +18,6 @@ type ApplyOptions struct {
 	DetailedExitcode bool
 	// StripTrailingCR is true if trailing carriage returns should be stripped during diffing
 	StripTrailingCR bool
-	// TODO: Remove this function once Helmfile v0.x
-	// DEPRECATED: Use skip-cleanup instead
-	RetainValuesFiles bool
-
 	// SkipCleanup is true if the cleanup of temporary values files should be skipped
 	SkipCleanup bool
 	// SkipCRDs is true if the CRDs should be skipped
@@ -54,7 +50,7 @@ type ApplyOptions struct {
 	WaitRetries int
 	// WaitForJobs is true if the helm command should wait for the jobs to be completed
 	WaitForJobs bool
-	// Propagate '--skipSchemaValidation' to helmv3 template and helm install
+	// Propagate '--skip-schema-validation' to helmv3 template and helm install
 	SkipSchemaValidation bool
 	// ReuseValues is true if the helm command should reuse the values
 	ReuseValues bool
@@ -75,6 +71,8 @@ type ApplyOptions struct {
 
 	// TakeOwnership is true if the ownership should be taken
 	TakeOwnership bool
+
+	SyncReleaseLabels bool
 }
 
 // NewApply creates a new Apply
@@ -123,7 +121,7 @@ func (a *ApplyImpl) StripTrailingCR() bool {
 
 // DiffOutput returns the diff output.
 func (a *ApplyImpl) DiffOutput() string {
-	return a.ApplyOptions.Output
+	return a.Output
 }
 
 // IncludeNeeds returns the include needs.
@@ -141,12 +139,6 @@ func (a *ApplyImpl) IncludeTransitiveNeeds() bool {
 	return a.ApplyOptions.IncludeTransitiveNeeds
 }
 
-// TODO: Remove this function once Helmfile v0.x
-// RetainValuesFiles returns the retain values files.
-func (a *ApplyImpl) RetainValuesFiles() bool {
-	return a.ApplyOptions.RetainValuesFiles
-}
-
 // ShowSecrets returns the show secrets.
 func (a *ApplyImpl) ShowSecrets() bool {
 	return a.ApplyOptions.ShowSecrets
@@ -276,3 +268,8 @@ func (a *ApplyImpl) HideNotes() bool {
 func (a *ApplyImpl) TakeOwnership() bool {
 	return a.ApplyOptions.TakeOwnership
 }
+
+// SyncReleaseLabels returns the SyncReleaseLabels.
+func (a *ApplyImpl) SyncReleaseLabels() bool {
+	return a.ApplyOptions.SyncReleaseLabels
+}
