@@ -4,15 +4,12 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/require"
-
-	"github.com/helmfile/helmfile/pkg/runtime"
 )
 
 func TestForbidEnvironmentsWithReleases(t *testing.T) {
 	testCases := []struct {
 		name        string
 		filePath    string
-		v1mode      bool
 		content     []byte
 		expectedErr bool
 		isStrict    bool
@@ -21,7 +18,6 @@ func TestForbidEnvironmentsWithReleases(t *testing.T) {
 			name:        "no error when only releases",
 			filePath:    "helmfile.yaml",
 			content:     []byte("releases:\n"),
-			v1mode:      false,
 			expectedErr: false,
 			isStrict:    false,
 		},
@@ -29,7 +25,6 @@ func TestForbidEnvironmentsWithReleases(t *testing.T) {
 			name:        "no error when only environments",
 			filePath:    "helmfile.yaml",
 			content:     []byte("environments:\n"),
-			v1mode:      false,
 			expectedErr: false,
 			isStrict:    false,
 		},
@@ -37,7 +32,6 @@ func TestForbidEnvironmentsWithReleases(t *testing.T) {
 			name:        "no error when has --- between releases and environments",
 			filePath:    "helmfile.yaml",
 			content:     []byte("environments:\n---\nreleases:\n"),
-			v1mode:      false,
 			expectedErr: false,
 			isStrict:    false,
 		},
@@ -45,7 +39,6 @@ func TestForbidEnvironmentsWithReleases(t *testing.T) {
 			name:        "no error when has --- between releases and environments, and --- on top of helmfile.yaml.gotmpl",
 			filePath:    "helmfile.yaml",
 			content:     []byte("---\nenvironments:\n---\nreleases:\n"),
-			v1mode:      false,
 			expectedErr: false,
 			isStrict:    false,
 		},
@@ -53,32 +46,17 @@ func TestForbidEnvironmentsWithReleases(t *testing.T) {
 			name:        "error when both releases and environments",
 			filePath:    "helmfile.yaml",
 			content:     []byte("environments:\nreleases:\n"),
-			v1mode:      false,
-			expectedErr: true,
-			isStrict:    false,
-		},
-		{
-			name:        "error when both releases and environments for plain yaml on v1",
-			filePath:    "helmfile.yaml",
-			content:     []byte("environments:\nreleases:\n"),
-			v1mode:      true,
 			expectedErr: true,
 			isStrict:    true,
 		},
 	}
 
-	v1mode := runtime.V1Mode
-	t.Cleanup(func() {
-		runtime.V1Mode = v1mode
-	})
-
 	for _, tc := range testCases {
 		t.Run(tc.name, func(t *testing.T) {
-			runtime.V1Mode = tc.v1mode
 			isStrict, err := forbidEnvironmentsWithReleases(tc.filePath, tc.content)
 			require.Equal(t, tc.isStrict, isStrict, "expected isStrict=%v, got=%v", tc.isStrict, isStrict)
 			if tc.expectedErr {
-				require.ErrorIsf(t, err, EnvironmentsAndReleasesWithinSameYamlPartErr, "expected error=%v, got=%v", EnvironmentsAndReleasesWithinSameYamlPartErr, err)
+				require.ErrorIsf(t, err, ErrEnvironmentsAndReleasesWithinSameYamlPart, "expected error=%v, got=%v", ErrEnvironmentsAndReleasesWithinSameYamlPart, err)
 			} else {
 				require.NoError(t, err, "expected no error but got error: %v", err)
 			}
@@ -153,26 +131,31 @@ func TestTopConfigKeysVerifier(t *testing.T) {
 			name:            "error when not correct order 00",
 			helmfileContent: []byte("releases:\nbases:\n"),
 			wantErr:         true,
+			wantStrict:      true,
 		},
 		{
 			name:            "error when not correct order 01",
 			helmfileContent: []byte("releases:\nhelmDefaults:\nbases:\n"),
 			wantErr:         true,
+			wantStrict:      true,
 		},
 		{
 			name:            "error when not correct order 02",
 			helmfileContent: []byte("helmDefaults:\nreleases:\nbases:\n"),
 			wantErr:         true,
+			wantStrict:      true,
 		},
 		{
 			name:            "error when not correct order 03",
 			helmfileContent: []byte("releases:\nva:\nve:\nbases:\n"),
 			wantErr:         true,
+			wantStrict:      true,
 		},
 		{
 			name:            "error when not correct order 04",
 			helmfileContent: []byte("bases:\nreleases:\nenvironments:\n"),
 			wantErr:         true,
+			wantStrict:      true,
 		},
 		{
 			name:            "no error when only has bases",
