@@ -6,7 +6,6 @@ import (
 	"path/filepath"
 	"slices"
 	"sort"
-	"strconv"
 	"strings"
 
 	"github.com/helmfile/chartify"
@@ -158,31 +157,17 @@ func (st *HelmState) appendWaitForJobsFlags(flags []string, release *ReleaseSpec
 	return flags
 }
 
-func (st *HelmState) appendWaitFlags(flags []string, helm helmexec.Interface, release *ReleaseSpec, ops *SyncOpts) []string {
-	var hasWait bool
+func (st *HelmState) appendWaitFlags(flags []string, release *ReleaseSpec, ops *SyncOpts) []string {
 	switch {
 	case release.Wait != nil && *release.Wait:
-		hasWait = true
 		flags = append(flags, "--wait")
 	case ops != nil && ops.Wait:
-		hasWait = true
 		flags = append(flags, "--wait")
 	case release.Wait == nil && st.HelmDefaults.Wait:
-		hasWait = true
 		flags = append(flags, "--wait")
 	}
-	// see https://github.com/helm/helm/releases/tag/v3.15.0
-	// https://github.com/helm/helm/commit/fc74964
-	if hasWait && helm.IsVersionAtLeast("3.15.0") {
-		switch {
-		case release.WaitRetries != nil && *release.WaitRetries > 0:
-			flags = append(flags, "--wait-retries", strconv.Itoa(*release.WaitRetries))
-		case ops != nil && ops.WaitRetries > 0:
-			flags = append(flags, "--wait-retries", strconv.Itoa(ops.WaitRetries))
-		case release.WaitRetries == nil && st.HelmDefaults.WaitRetries > 0:
-			flags = append(flags, "--wait-retries", strconv.Itoa(st.HelmDefaults.WaitRetries))
-		}
-	}
+	// Note: --wait-retries flag has been removed from Helm and is no longer supported
+	// WaitRetries configuration is preserved for backward compatibility but ignored
 	return flags
 }
 
